@@ -8,8 +8,8 @@ fit_mipo <- mice::pool(fit_mira)
 test_that("glance.mipo: nhanes lm", {
   tmp <- glance(fit_mipo)
   expect_true(inherits(tmp, "data.frame"))
-  expect_equal(tmp$adj.r.squared[1], 0.462, tolerance = .001)
-  expect_equal(tmp$r.squared[1], 0.509, tolerance = .001)
+  expect_equal(tmp$adj.r.squared[1], 0.4966436, tolerance = .00001)
+  expect_equal(tmp$r.squared[1], 0.539119, tolerance = .00001)
 })
 
 test_that("tidy.mipo: nhanes lm", {
@@ -21,13 +21,15 @@ test_that("tidy.mipo: nhanes lm", {
   expect_true(inherits(tmp, "data.frame"))
   expect_equal(dim(tmp), c(3, 15))
   expect_equal(tmp$conf.low, c(
-    -528.82, 9.76, -5.90
-  ), tolerance = 0.01)
+    -171.676808396086, -12.5277617578218,
+    3.42203157045941
+  ))
 
   tmp <- tidy(fit_mipo, conf.int = TRUE, conf.level = .99)
   expect_true(inherits(tmp, "data.frame"))
   expect_equal(dim(tmp), c(3, 15))
   expect_equal(tmp$conf.low, c(
-    -1237.32, -5.69, -20.82
-  ), tolerance = 0.01)
+    -216.910255354075, -63.8124944550467,
+    2.16193377446054
+  ))
 })
